@@ -11,7 +11,8 @@
 
 int sanlock_status(int debug, char sort_arg);
 int sanlock_host_status(int debug, char *lockspace_name);
+int sanlock_renewal(char *lockspace_name);
 int sanlock_log_dump(int max_size);
-int sanlock_shutdown(uint32_t force);
+int sanlock_shutdown(uint32_t force, int wait_result);
 
 #endif
