@@ -458,6 +458,9 @@ void send_result(int ci, int fd, struct sm_header *h_recv, int result);
 void send_result(int ci, int fd, struct sm_header *h_recv, int result)
 {
 	struct sm_header h;
+	size_t rem = sizeof(h);
+	size_t off = 0;
+	ssize_t rv;
 
 	log_client(ci, fd, "send %d", result);
 
@@ -466,7 +469,18 @@ void send_result(int ci, int fd, struct sm_header *h_recv, int result)
 	h.length = sizeof(h);
 	h.data = result;
 	h.data2 = 0;
-	send(fd, &h, sizeof(h), MSG_NOSIGNAL);
+
+retry:
+	rv = send(fd, (char *)&h + off, rem, MSG_NOSIGNAL);
+	if (rv == -1 && errno == EINTR)
+		goto retry;
+	if (rv < 0)
+		return;
+	if (rv < rem) {
+		rem -= rv;
+		off += rv;
+		goto retry;
+	}
 }
 
 void client_pid_dead(int ci);
@@ -932,6 +946,9 @@ static void *thread_pool_worker(void *data)
 
 	while (1) {
 		while (!pool.quit && list_empty(&pool.work_data)) {
+			if (pool.free_workers >= DEFAULT_MIN_WORKER_THREADS)
+				goto out;
+
 			pool.free_workers++;
 			pthread_cond_wait(&pool.cond, &pool.mutex);
 			pool.free_workers--;
@@ -952,6 +969,7 @@ static void *thread_pool_worker(void *data)
 			break;
 	}
 
+out:
 	pool.num_workers--;
 	if (!pool.num_workers)
 		pthread_cond_signal(&pool.quit_wait);
@@ -1227,37 +1245,40 @@ static void process_connection(int ci)
 
 	memset(&h, 0, sizeof(h));
 
+ retry:
 	rv = recv(client[ci].fd, &h, sizeof(h), MSG_WAITALL);
+	if (rv == -1 && errno == EINTR)
+		goto retry;
 	if (!rv)
 		goto dead;
 
-	log_client(ci, client[ci].fd, "recv %d %d", rv, h.cmd);
+	log_client(ci, client[ci].fd, "recv %d %u", rv, h.cmd);
 
 	if (rv < 0) {
-		log_error("ci %d fd %d pid %d recv errno %d",
-			  ci, client[ci].fd, client[ci].pid, errno);
-		goto dead;
+		log_error("client connection %d %d %d recv msg header rv %d errno %d",
+			  ci, client[ci].fd, client[ci].pid, rv, errno);
+		goto bad;
 	}
 	if (rv != sizeof(h)) {
-		log_error("ci %d fd %d pid %d recv size %d",
-			  ci, client[ci].fd, client[ci].pid, rv);
-		goto dead;
+		log_error("client connection %d %d %d recv msg header rv %d cmd %u len %u",
+			  ci, client[ci].fd, client[ci].pid, rv, h.cmd, h.length);
+		goto bad;
 	}
 	if (h.magic != SM_MAGIC) {
-		log_error("ci %d recv %d magic %x vs %x",
-			  ci, rv, h.magic, SM_MAGIC);
-		goto dead;
+		log_error("client connection %d %d %d recv msg header rv %d cmd %u len %u magic %x vs %x",
+			  ci, client[ci].fd, client[ci].pid, rv, h.cmd, h.length, h.magic, SM_MAGIC);
+		goto bad;
 	}
 	if (client[ci].restricted & SANLK_RESTRICT_ALL) {
-		log_error("ci %d fd %d pid %d cmd %d restrict all",
-			  ci, client[ci].fd, client[ci].pid, h.cmd);
-		goto dead;
+		log_error("client connection %d %d %d recv msg header rv %d cmd %u len %u restrict all",
+			  ci, client[ci].fd, client[ci].pid, rv, h.cmd, h.length);
+		goto bad;
 	}
 	if (h.version && (h.cmd != SM_CMD_VERSION) &&
 	    (h.version & 0xFFFF0000) > (SM_PROTO & 0xFFFF0000)) {
-		log_error("ci %d recv %d proto %x vs %x",
-			  ci, rv, h.version , SM_PROTO);
-		goto dead;
+		log_error("client connection %d %d %d recv msg header rv %d cmd %u len %u version %x",
+			  ci, client[ci].fd, client[ci].pid, rv, h.cmd, h.length, h.version);
+		goto bad;
 	}
 
 	client[ci].cmd_last = h.cmd;
@@ -1302,7 +1323,7 @@ static void process_connection(int ci)
 	case SM_CMD_DELETE_RESOURCE:
 		rv = client_suspend(ci);
 		if (rv < 0)
-			goto dead;
+			goto bad;
 		process_cmd_thread_unregistered(ci, &h);
 		break;
 	case SM_CMD_ACQUIRE:
@@ -1314,16 +1335,20 @@ static void process_connection(int ci)
 		   while the thread is working on it */
 		rv = client_suspend(ci);
 		if (rv < 0)
-			goto dead;
+			goto bad;
 		process_cmd_thread_registered(ci, &h);
 		break;
 	default:
-		log_error("process_connection ci %d fd %d cmd %d unknown", ci, client[ci].fd, h.cmd);
-		goto dead;
+		log_error("client connection ci %d fd %d pid %d cmd %d unknown",
+			  ci, client[ci].fd, client[ci].pid, h.cmd);
+		goto bad;
 	};
 
 	return;
 
+ bad:
+	return;
+
  dead:
 	log_client(ci, client[ci].fd, "recv dead");
 	deadfn = client[ci].deadfn;
@@ -2877,6 +2902,13 @@ static void read_config_file(void)
 			} else {
 				log_error("ignore unknown max_sectors_kb %s", str);
 			}
+
+		} else if (!strcmp(str, "max_worker_threads")) {
+			get_val_int(line, &val);
+			if (val < DEFAULT_MIN_WORKER_THREADS)
+				val = DEFAULT_MIN_WORKER_THREADS;
+			com.max_worker_threads = val;
+
 		}
 	}
 
